window.Gleam.initSearch([{"doc":"showtime","title":"showtime","content":"![](https://raw.githubusercontent.com/JohnBjrk/showtime/main/assets/images/showtime2.png)\n\nTest framework for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/showtime)](https://hex.pm/packages/showtime)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/showtime/)\n\n## Introduction\n\nShowtime is a test framework for Gleam. It can be used in the same way as Gleeunit and intends to support the same API so that migration can be done by simply changing some imports.\n\nIn addition to supporting the same features as Gleeunit showtime add some more features:\n\n- Unified report of test-failures on erlang and javascript target\n- Diff of equality asserts on strings and lists\n- Parallell execution of test-modules on erlang target\n- Possible to run specific test-modules\n\nShowtime also adds a new way to specify tests with related meta-data which gives the following capabilities:\n\n- Possible to ignore tests based on tags\n- Test can have descriptions which will be shown in the test-report\n\n## How to use\n\nIn your main test-file, replace:\n\n```gleam\ngleeunit.main()\n```\n\nwith:\n\n```gleam\nshowtime.main()\n```\n\nIts also possible to replace the import:\n\n```gleam\nimport gleeunit/should\n```\n\nwith:\n\n```gleam\nimport showtime/tests/should\n```\n\nThis should improve the test-report since showtime can make more assumption on the data passed when\nfailing an assertion.\n\n## Installation\n\n```sh\ngleam add showtime\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/showtime&gt;.\n\n## Name\n\nThe name &quot;showtime&quot; is a nod to the Gleam test framework &quot;gleeunit&quot; which surely must have something to do with the TV series 📺.\n","url":"index.html"},{"doc":"showtime/tests/meta","title":"Meta","content":"pub type Meta {\n  Meta(description: String, tags: List(String))\n}\n\nMeta(description: String, tags: List(String))\n\n\nSynonyms:\nshowtime/tests/meta.Meta\nshowtime/tests/meta Meta","url":"showtime/tests/meta.html#Meta"},{"doc":"showtime/tests/meta","title":"showtime/tests/meta","content":"","url":"showtime/tests/meta.html"},{"doc":"showtime/tests/should","title":"Assertion","content":"pub type Assertion(t, e) {\n  Eq(a: t, b: t, meta: Option(Meta))\n  NotEq(a: t, b: t, meta: Option(Meta))\n  IsOk(a: Result(t, e), meta: Option(Meta))\n  IsError(a: Result(t, e), meta: Option(Meta))\n  Fail(meta: Option(Meta))\n}\n\nEq(a: t, b: t, meta: Option(Meta))\n\n\nNotEq(a: t, b: t, meta: Option(Meta))\n\n\nIsOk(a: Result(t, e), meta: Option(Meta))\n\n\nIsError(a: Result(t, e), meta: Option(Meta))\n\n\nFail(meta: Option(Meta))\n\n\nSynonyms:\nshowtime/tests/should.Assertion\nshowtime/tests/should Assertion","url":"showtime/tests/should.html#Assertion"},{"doc":"showtime/tests/should","title":"be_error","content":"pub fn be_error(a: Result(a, b)) -&gt; b\n\nSynonyms:\nshowtime/tests/should.be_error\nshowtime/tests/should be_error","url":"showtime/tests/should.html#be_error"},{"doc":"showtime/tests/should","title":"be_error_meta","content":"pub fn be_error_meta(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_error_meta\nshowtime/tests/should be_error_meta","url":"showtime/tests/should.html#be_error_meta"},{"doc":"showtime/tests/should","title":"be_false","content":"pub fn be_false(a: Bool) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_false\nshowtime/tests/should be_false","url":"showtime/tests/should.html#be_false"},{"doc":"showtime/tests/should","title":"be_false_meta","content":"pub fn be_false_meta(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_false_meta\nshowtime/tests/should be_false_meta","url":"showtime/tests/should.html#be_false_meta"},{"doc":"showtime/tests/should","title":"be_ok","content":"pub fn be_ok(a: Result(a, b)) -&gt; a\n\nSynonyms:\nshowtime/tests/should.be_ok\nshowtime/tests/should be_ok","url":"showtime/tests/should.html#be_ok"},{"doc":"showtime/tests/should","title":"be_ok_meta","content":"pub fn be_ok_meta(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_ok_meta\nshowtime/tests/should be_ok_meta","url":"showtime/tests/should.html#be_ok_meta"},{"doc":"showtime/tests/should","title":"be_true","content":"pub fn be_true(a: Bool) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_true\nshowtime/tests/should be_true","url":"showtime/tests/should.html#be_true"},{"doc":"showtime/tests/should","title":"be_true_meta","content":"pub fn be_true_meta(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_true_meta\nshowtime/tests/should be_true_meta","url":"showtime/tests/should.html#be_true_meta"},{"doc":"showtime/tests/should","title":"equal","content":"pub fn equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.equal\nshowtime/tests/should equal","url":"showtime/tests/should.html#equal"},{"doc":"showtime/tests/should","title":"equal_meta","content":"pub fn equal_meta(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.equal_meta\nshowtime/tests/should equal_meta","url":"showtime/tests/should.html#equal_meta"},{"doc":"showtime/tests/should","title":"evaluate","content":"pub fn evaluate(assertion: Assertion(a, b)) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.evaluate\nshowtime/tests/should evaluate","url":"showtime/tests/should.html#evaluate"},{"doc":"showtime/tests/should","title":"fail","content":"pub fn fail() -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.fail\nshowtime/tests/should fail","url":"showtime/tests/should.html#fail"},{"doc":"showtime/tests/should","title":"fail_meta","content":"pub fn fail_meta(meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.fail_meta\nshowtime/tests/should fail_meta","url":"showtime/tests/should.html#fail_meta"},{"doc":"showtime/tests/should","title":"not_equal","content":"pub fn not_equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.not_equal\nshowtime/tests/should not_equal","url":"showtime/tests/should.html#not_equal"},{"doc":"showtime/tests/should","title":"not_equal_meta","content":"pub fn not_equal_meta(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.not_equal_meta\nshowtime/tests/should not_equal_meta","url":"showtime/tests/should.html#not_equal_meta"},{"doc":"showtime/tests/should","title":"showtime/tests/should","content":"","url":"showtime/tests/should.html"},{"doc":"showtime","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nshowtime.main\nshowtime main","url":"showtime.html#main"},{"doc":"showtime","title":"showtime","content":"","url":"showtime.html"},{"doc":"showtime/tests/do_test","title":"MetaShould","content":"pub type MetaShould(t) {\n  MetaShould(equal: fn(t, t) -&gt; Nil, not_equal: fn(t, t) -&gt; Nil)\n}\n\nMetaShould(equal: fn(t, t) -&gt; Nil, not_equal: fn(t, t) -&gt; Nil)\n\n\nSynonyms:\nshowtime/tests/do_test.MetaShould\nshowtime/tests/do_test MetaShould","url":"showtime/tests/do_test.html#MetaShould"},{"doc":"showtime/tests/do_test","title":"Test","content":"pub type Test {\n  Test(meta: Meta, test_function: fn() -&gt; Nil)\n}\n\nTest(meta: Meta, test_function: fn() -&gt; Nil)\n\n\nSynonyms:\nshowtime/tests/do_test.Test\nshowtime/tests/do_test Test","url":"showtime/tests/do_test.html#Test"},{"doc":"showtime/tests/do_test","title":"be_error","content":"pub fn be_error(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/do_test.be_error\nshowtime/tests/do_test be_error","url":"showtime/tests/do_test.html#be_error"},{"doc":"showtime/tests/do_test","title":"be_false","content":"pub fn be_false(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/do_test.be_false\nshowtime/tests/do_test be_false","url":"showtime/tests/do_test.html#be_false"},{"doc":"showtime/tests/do_test","title":"be_ok","content":"pub fn be_ok(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/do_test.be_ok\nshowtime/tests/do_test be_ok","url":"showtime/tests/do_test.html#be_ok"},{"doc":"showtime/tests/do_test","title":"be_true","content":"pub fn be_true(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/do_test.be_true\nshowtime/tests/do_test be_true","url":"showtime/tests/do_test.html#be_true"},{"doc":"showtime/tests/do_test","title":"do_test","content":"pub fn do_test(\n  meta: Meta,\n  test_function: fn(Meta) -&gt; Nil,\n) -&gt; Test\n\nSynonyms:\nshowtime/tests/do_test.do_test\nshowtime/tests/do_test do_test","url":"showtime/tests/do_test.html#do_test"},{"doc":"showtime/tests/do_test","title":"equal","content":"pub fn equal(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/do_test.equal\nshowtime/tests/do_test equal","url":"showtime/tests/do_test.html#equal"},{"doc":"showtime/tests/do_test","title":"fail","content":"pub fn fail(meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/do_test.fail\nshowtime/tests/do_test fail","url":"showtime/tests/do_test.html#fail"},{"doc":"showtime/tests/do_test","title":"not_equal","content":"pub fn not_equal(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/do_test.not_equal\nshowtime/tests/do_test not_equal","url":"showtime/tests/do_test.html#not_equal"},{"doc":"showtime/tests/do_test","title":"with_meta","content":"pub fn with_meta(\n  meta: Meta,\n  test_function: fn(MetaShould(a)) -&gt; Nil,\n) -&gt; Test\n\nSynonyms:\nshowtime/tests/do_test.with_meta\nshowtime/tests/do_test with_meta","url":"showtime/tests/do_test.html#with_meta"},{"doc":"showtime/tests/do_test","title":"showtime/tests/do_test","content":"","url":"showtime/tests/do_test.html"}]);